@@ -60,7 +60,7 @@ where
         let depth = self.inner.read_i32::<LittleEndian>()?;
         let aux = read_aux(&mut self.inner)?;
         let reference_sequences = read_reference_sequences(&mut self.inner, depth)?;
-        let n_no_coor = self.inner.read_u64::<LittleEndian>().ok();
+        let n_no_coor = read_unplaced_unmapped_record_count(&mut self.inner)?;
 
         let mut builder = Index::builder()
             .set_min_shift(min_shift)
@@ -215,6 +215,17 @@ where
     Ok(Metadata::new(ref_beg, ref_end, n_mapped, n_unmapped))
 }
 
+fn read_unplaced_unmapped_record_count<R>(reader: &mut R) -> io::Result<Option<u64>>
+where
+    R: Read,
+{
+    match reader.read_u64::<LittleEndian>() {
+        Ok(n) => Ok(Some(n)),
+        Err(ref e) if e.kind() == io::ErrorKind::UnexpectedEof => Ok(None),
+        Err(e) => Err(e),
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -274,4 +285,17 @@ mod tests {
 
         Ok(())
     }
+
+    #[test]
+    fn test_read_unplaced_unmapped_record_count() -> io::Result<()> {
+        let data = [];
+        let mut reader = &data[..];
+        assert_eq!(read_unplaced_unmapped_record_count(&mut reader)?, None);
+
+        let data = [0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00];
+        let mut reader = &data[..];
+        assert_eq!(read_unplaced_unmapped_record_count(&mut reader)?, Some(8));
+
+        Ok(())
+    }
 }
